@@ -2,6 +2,7 @@
  *  arch-tag: Header with definitions for Rhythmbox icon loading
  *
  *  Copyright (C) 2002 Jorn Baayen
+ *  Copyright (C) 2004 Colin Walters <walters@verbum.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -53,8 +54,12 @@ G_BEGIN_DECLS
 #define RB_STOCK_NO_STAR       "rhythmbox-no-star"
 #define RB_STOCK_AUDIOCD       "rhythmbox-audiocd"
 #define RB_STOCK_DND_ICON      "rhythmbox-dnd"
+#define RB_STOCK_IPOD          "rhythmbox-ipod"
+
+void	rb_stock_icons_init	(void);
+
+void	rb_stock_icons_shutdown (void);
 
-void rb_stock_icons_init (void);
 
 G_END_DECLS
 
