@@ -433,6 +433,25 @@ rb_query_creator_load_query (RBQueryCreator *creator, GPtrArray *query,
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (creator->priv->disjunction_check),
 				      disjunction);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (creator->priv->limit_check),
+				      limit_count || limit_size);
+	if (limit_count) {
+		char *str = g_strdup_printf ("%d", limit_count);
+		gtk_option_menu_set_history (GTK_OPTION_MENU (creator->priv->limit_option), 0);
+		gtk_entry_set_text (GTK_ENTRY (creator->priv->limit_entry), str);
+		g_free (str);
+	} else if (limit_size > 0 && limit_size < 1000) {
+		char *str = g_strdup_printf ("%d", limit_size);
+		gtk_option_menu_set_history (GTK_OPTION_MENU (creator->priv->limit_option), 1);
+		gtk_entry_set_text (GTK_ENTRY (creator->priv->limit_entry), str);
+		g_free (str);
+	} else if (limit_size >= 1000) {
+		char *str = g_strdup_printf ("%d", limit_size / 1000);
+		gtk_option_menu_set_history (GTK_OPTION_MENU (creator->priv->limit_option), 2);
+		gtk_entry_set_text (GTK_ENTRY (creator->priv->limit_entry), str);
+		g_free (str);
+	}
 }
 
 GtkWidget *
